# -*- coding: utf-8 -*-
"""Declaration of metadata for the package."""

__title__ = "flloat"
__description__ = "A Python implementation of the FLLOAT library."
__url__ = "https://github.com/whitemech/flloat.git"
__version__ = "0.3.0"
__author__ = "Marco Favorito"
__author_email__ = "marco.favorito@gmail.com"
__license__ = "Apache license"
__copyright__ = "2019 Marco Favorito"
